0.14 (2022-04-14)
-----------------

- Fix command registration
- Check registered decks for banned cards


0.13 (2022-04-14)
-----------------

- Improve command registration


0.12 (2022-04-14)
-----------------

- Handle new VDB domain name (now vdb.im)


0.11 (2022-04-02)
-----------------

- Alpha V1
- Using PostgreSQL as backend database for easier external tooling
- Clear separation between internal logic and bot interface for future interfaces
- Using slash commands for better UX
- Tests pending
- Archon files export unavailable
- Probably quite a few bugs remaining, to be field-tested

0.10 (2022-01-03)
-----------------

- Fix KRCG version to old seating for now.


0.9 (2022-01-03)
----------------

- Fix VPs check on finals
- Indicate count in Players and Registrations
- Remove read access to finals text channels (so table password can be shared easily)

0.8 (2021-12-13)
----------------

- Improve VEKN API logging


0.7 (2021-11-22)
----------------

- Fix checkin with spurious name
- Fix rounds limit


0.6 (2021-11-06)
----------------

- Fix ``rounds-limit`` message
- Fix checkin on round limits


0.5 (2021-10-24)
----------------

- Add self-registration for players
- Add the possibility to limit the nuumber of rounds


0.4 (2021-09-28)
----------------

- Fixed judge checkin
- Improved archon help: now display judges commands in the judges channel only
- Fixed round-add


0.3 (2021-09-26)
----------------

- Players list fixed: only checked-in players are now displayed


0.2 (2021-07-07)
----------------

- Fix main


0.1 (2021-07-07)
----------------

- First public version
